languages — Transifex v0.8.0 documentation

# Transifex v0.8.0 documentation

# `languages`

## Feeds

## Models

class `Language`(*args, **kwargs)
  A spoken language or dialect, with a distinct locale.

`suite`()
  Define this application’s testing suite for Django’s test runner.

## Views

`slug_feed`(request, slug=None, param='', feed_dict=None)

  Override default feed, using custom (including inexistent) slug.

  Provides the functionality needed to decouple the Feed’s slug from the urlconf, so a feed mounted at “^/feed” can exist.

  See also http://code.djangoproject.com/ticket/6969.